/*
** Copyright (C) 2006 Thadeu Lima de Souza Cascardo <cascardo@minaslivre.org>
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#include <glib.h>
#include <syslog.h>

static int map_level (GLogLevelFlags level)
{
  if (level & G_LOG_LEVEL_ERROR)
    return LOG_CRIT;
  if (level & G_LOG_LEVEL_CRITICAL)
    return LOG_ERR;
  if (level & G_LOG_LEVEL_WARNING)
    return LOG_WARNING;
  if (level & G_LOG_LEVEL_MESSAGE)
    return LOG_NOTICE;
  if (level & G_LOG_LEVEL_INFO)
    return LOG_INFO;
  if (level & G_LOG_LEVEL_DEBUG)
    return LOG_DEBUG;
}

static void log_func (const gchar* domain,
		      GLogLevelFlags level,
		      const gchar* message,
		      gpointer data)
{
  syslog (map_level (level), "%s", message);
}

void pop_log_init ()
{
  openlog ("popproxy", LOG_NDELAY | LOG_NOWAIT, LOG_DAEMON);
  g_log_set_handler (NULL, G_LOG_LEVEL_MASK | G_LOG_FLAG_FATAL
		     | G_LOG_FLAG_RECURSION, log_func, NULL);
}
